@@ -146,9 +146,15 @@ impl<'a, AUTHENTICATIONCODETYPE: TDAuthenticationCodeType> TDAuthenticationCodeT
 impl<'a, AUTHORIZATIONSTATE: TDAuthorizationState> TDAuthorizationState for &'a AUTHORIZATIONSTATE {}
 impl<'a, AUTHORIZATIONSTATE: TDAuthorizationState> TDAuthorizationState for &'a mut AUTHORIZATIONSTATE {}
 
+impl<'a, BACKGROUNDTYPE: TDBackgroundType> TDBackgroundType for &'a BACKGROUNDTYPE {}
+impl<'a, BACKGROUNDTYPE: TDBackgroundType> TDBackgroundType for &'a mut BACKGROUNDTYPE {}
+
 impl<'a, CALLDISCARDREASON: TDCallDiscardReason> TDCallDiscardReason for &'a CALLDISCARDREASON {}
 impl<'a, CALLDISCARDREASON: TDCallDiscardReason> TDCallDiscardReason for &'a mut CALLDISCARDREASON {}
 
+impl<'a, CALLPROBLEM: TDCallProblem> TDCallProblem for &'a CALLPROBLEM {}
+impl<'a, CALLPROBLEM: TDCallProblem> TDCallProblem for &'a mut CALLPROBLEM {}
+
 impl<'a, CALLSTATE: TDCallState> TDCallState for &'a CALLSTATE {}
 impl<'a, CALLSTATE: TDCallState> TDCallState for &'a mut CALLSTATE {}
 
@@ -191,6 +197,9 @@ impl<'a, INLINEKEYBOARDBUTTONTYPE: TDInlineKeyboardButtonType> TDInlineKeyboardB
 impl<'a, INLINEQUERYRESULT: TDInlineQueryResult> TDInlineQueryResult for &'a INLINEQUERYRESULT {}
 impl<'a, INLINEQUERYRESULT: TDInlineQueryResult> TDInlineQueryResult for &'a mut INLINEQUERYRESULT {}
 
+impl<'a, INPUTBACKGROUND: TDInputBackground> TDInputBackground for &'a INPUTBACKGROUND {}
+impl<'a, INPUTBACKGROUND: TDInputBackground> TDInputBackground for &'a mut INPUTBACKGROUND {}
+
 impl<'a, INPUTCREDENTIALS: TDInputCredentials> TDInputCredentials for &'a INPUTCREDENTIALS {}
 impl<'a, INPUTCREDENTIALS: TDInputCredentials> TDInputCredentials for &'a mut INPUTCREDENTIALS {}
 
@@ -338,6 +347,7 @@ pub enum TdType {
   UpdateChatNotificationSettings(UpdateChatNotificationSettings),
   UpdateChatOnlineMemberCount(UpdateChatOnlineMemberCount),
   UpdateChatOrder(UpdateChatOrder),
+  UpdateChatPermissions(UpdateChatPermissions),
   UpdateChatPhoto(UpdateChatPhoto),
   UpdateChatPinnedMessage(UpdateChatPinnedMessage),
   UpdateChatReadInbox(UpdateChatReadInbox),
@@ -380,6 +390,7 @@ pub enum TdType {
   UpdateSavedAnimations(UpdateSavedAnimations),
   UpdateScopeNotificationSettings(UpdateScopeNotificationSettings),
   UpdateSecretChat(UpdateSecretChat),
+  UpdateSelectedBackground(UpdateSelectedBackground),
   UpdateServiceNotification(UpdateServiceNotification),
   UpdateSupergroup(UpdateSupergroup),
   UpdateSupergroupFullInfo(UpdateSupergroupFullInfo),
@@ -404,6 +415,9 @@ pub enum TdType {
   AccountTtl(AccountTtl),
   Animations(Animations),
   AuthenticationCodeInfo(AuthenticationCodeInfo),
+  AutoDownloadSettingsPresets(AutoDownloadSettingsPresets),
+  Background(Background),
+  Backgrounds(Backgrounds),
   BasicGroup(BasicGroup),
   BasicGroupFullInfo(BasicGroupFullInfo),
   CallId(CallId),
@@ -422,6 +436,7 @@ pub enum TdType {
   DatabaseStatistics(DatabaseStatistics),
   DeepLinkInfo(DeepLinkInfo),
   EmailAddressAuthenticationCodeInfo(EmailAddressAuthenticationCodeInfo),
+  Emojis(Emojis),
   Error(Error),
   File(File),
   FilePart(FilePart),
@@ -438,6 +453,7 @@ pub enum TdType {
   LogTags(LogTags),
   LogVerbosityLevel(LogVerbosityLevel),
   Message(Message),
+  MessageLinkInfo(MessageLinkInfo),
   Messages(Messages),
   NetworkStatistics(NetworkStatistics),
   Ok(Ok),
@@ -458,7 +474,6 @@ pub enum TdType {
   Seconds(Seconds),
   SecretChat(SecretChat),
   Sessions(Sessions),
-  StickerEmojis(StickerEmojis),
   StickerSet(StickerSet),
   StickerSets(StickerSets),
   Stickers(Stickers),
@@ -484,7 +499,6 @@ pub enum TdType {
   UserProfilePhotos(UserProfilePhotos),
   Users(Users),
   ValidatedOrderInfo(ValidatedOrderInfo),
-  Wallpapers(Wallpapers),
   WebPage(WebPage),
   WebPageInstantView(WebPageInstantView),
 
@@ -509,6 +523,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateChatNotificationSettings, UpdateChatNotificationSettings);
   (updateChatOnlineMemberCount, UpdateChatOnlineMemberCount);
   (updateChatOrder, UpdateChatOrder);
+  (updateChatPermissions, UpdateChatPermissions);
   (updateChatPhoto, UpdateChatPhoto);
   (updateChatPinnedMessage, UpdateChatPinnedMessage);
   (updateChatReadInbox, UpdateChatReadInbox);
@@ -551,6 +566,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateSavedAnimations, UpdateSavedAnimations);
   (updateScopeNotificationSettings, UpdateScopeNotificationSettings);
   (updateSecretChat, UpdateSecretChat);
+  (updateSelectedBackground, UpdateSelectedBackground);
   (updateServiceNotification, UpdateServiceNotification);
   (updateSupergroup, UpdateSupergroup);
   (updateSupergroupFullInfo, UpdateSupergroupFullInfo);
@@ -575,6 +591,9 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (accountTtl, AccountTtl);
   (animations, Animations);
   (authenticationCodeInfo, AuthenticationCodeInfo);
+  (autoDownloadSettingsPresets, AutoDownloadSettingsPresets);
+  (background, Background);
+  (backgrounds, Backgrounds);
   (basicGroup, BasicGroup);
   (basicGroupFullInfo, BasicGroupFullInfo);
   (callId, CallId);
@@ -593,6 +612,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (databaseStatistics, DatabaseStatistics);
   (deepLinkInfo, DeepLinkInfo);
   (emailAddressAuthenticationCodeInfo, EmailAddressAuthenticationCodeInfo);
+  (emojis, Emojis);
   (error, Error);
   (file, File);
   (filePart, FilePart);
@@ -609,6 +629,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (logTags, LogTags);
   (logVerbosityLevel, LogVerbosityLevel);
   (message, Message);
+  (messageLinkInfo, MessageLinkInfo);
   (messages, Messages);
   (networkStatistics, NetworkStatistics);
   (ok, Ok);
@@ -629,7 +650,6 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (seconds, Seconds);
   (secretChat, SecretChat);
   (sessions, Sessions);
-  (stickerEmojis, StickerEmojis);
   (stickerSet, StickerSet);
   (stickerSets, StickerSets);
   (stickers, Stickers);
@@ -655,7 +675,6 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (userProfilePhotos, UserProfilePhotos);
   (users, Users);
   (validatedOrderInfo, ValidatedOrderInfo);
-  (wallpapers, Wallpapers);
   (webPage, WebPage);
   (webPageInstantView, WebPageInstantView);
 
@@ -683,6 +702,7 @@ impl RObject for TdType {
       Self::UpdateChatNotificationSettings(value) => value.td_name(),
       Self::UpdateChatOnlineMemberCount(value) => value.td_name(),
       Self::UpdateChatOrder(value) => value.td_name(),
+      Self::UpdateChatPermissions(value) => value.td_name(),
       Self::UpdateChatPhoto(value) => value.td_name(),
       Self::UpdateChatPinnedMessage(value) => value.td_name(),
       Self::UpdateChatReadInbox(value) => value.td_name(),
@@ -725,6 +745,7 @@ impl RObject for TdType {
       Self::UpdateSavedAnimations(value) => value.td_name(),
       Self::UpdateScopeNotificationSettings(value) => value.td_name(),
       Self::UpdateSecretChat(value) => value.td_name(),
+      Self::UpdateSelectedBackground(value) => value.td_name(),
       Self::UpdateServiceNotification(value) => value.td_name(),
       Self::UpdateSupergroup(value) => value.td_name(),
       Self::UpdateSupergroupFullInfo(value) => value.td_name(),
@@ -749,6 +770,9 @@ impl RObject for TdType {
       Self::AccountTtl(value) => value.td_name(),
       Self::Animations(value) => value.td_name(),
       Self::AuthenticationCodeInfo(value) => value.td_name(),
+      Self::AutoDownloadSettingsPresets(value) => value.td_name(),
+      Self::Background(value) => value.td_name(),
+      Self::Backgrounds(value) => value.td_name(),
       Self::BasicGroup(value) => value.td_name(),
       Self::BasicGroupFullInfo(value) => value.td_name(),
       Self::CallId(value) => value.td_name(),
@@ -767,6 +791,7 @@ impl RObject for TdType {
       Self::DatabaseStatistics(value) => value.td_name(),
       Self::DeepLinkInfo(value) => value.td_name(),
       Self::EmailAddressAuthenticationCodeInfo(value) => value.td_name(),
+      Self::Emojis(value) => value.td_name(),
       Self::Error(value) => value.td_name(),
       Self::File(value) => value.td_name(),
       Self::FilePart(value) => value.td_name(),
@@ -783,6 +808,7 @@ impl RObject for TdType {
       Self::LogTags(value) => value.td_name(),
       Self::LogVerbosityLevel(value) => value.td_name(),
       Self::Message(value) => value.td_name(),
+      Self::MessageLinkInfo(value) => value.td_name(),
       Self::Messages(value) => value.td_name(),
       Self::NetworkStatistics(value) => value.td_name(),
       Self::Ok(value) => value.td_name(),
@@ -803,7 +829,6 @@ impl RObject for TdType {
       Self::Seconds(value) => value.td_name(),
       Self::SecretChat(value) => value.td_name(),
       Self::Sessions(value) => value.td_name(),
-      Self::StickerEmojis(value) => value.td_name(),
       Self::StickerSet(value) => value.td_name(),
       Self::StickerSets(value) => value.td_name(),
       Self::Stickers(value) => value.td_name(),
@@ -829,7 +854,6 @@ impl RObject for TdType {
       Self::UserProfilePhotos(value) => value.td_name(),
       Self::Users(value) => value.td_name(),
       Self::ValidatedOrderInfo(value) => value.td_name(),
-      Self::Wallpapers(value) => value.td_name(),
       Self::WebPage(value) => value.td_name(),
       Self::WebPageInstantView(value) => value.td_name(),
     
@@ -853,6 +877,7 @@ impl RObject for TdType {
         Self::UpdateChatNotificationSettings(value) => value.extra(),
         Self::UpdateChatOnlineMemberCount(value) => value.extra(),
         Self::UpdateChatOrder(value) => value.extra(),
+        Self::UpdateChatPermissions(value) => value.extra(),
         Self::UpdateChatPhoto(value) => value.extra(),
         Self::UpdateChatPinnedMessage(value) => value.extra(),
         Self::UpdateChatReadInbox(value) => value.extra(),
@@ -895,6 +920,7 @@ impl RObject for TdType {
         Self::UpdateSavedAnimations(value) => value.extra(),
         Self::UpdateScopeNotificationSettings(value) => value.extra(),
         Self::UpdateSecretChat(value) => value.extra(),
+        Self::UpdateSelectedBackground(value) => value.extra(),
         Self::UpdateServiceNotification(value) => value.extra(),
         Self::UpdateSupergroup(value) => value.extra(),
         Self::UpdateSupergroupFullInfo(value) => value.extra(),
@@ -919,6 +945,9 @@ impl RObject for TdType {
         Self::AccountTtl(value) => value.extra(),
         Self::Animations(value) => value.extra(),
         Self::AuthenticationCodeInfo(value) => value.extra(),
+        Self::AutoDownloadSettingsPresets(value) => value.extra(),
+        Self::Background(value) => value.extra(),
+        Self::Backgrounds(value) => value.extra(),
         Self::BasicGroup(value) => value.extra(),
         Self::BasicGroupFullInfo(value) => value.extra(),
         Self::CallId(value) => value.extra(),
@@ -937,6 +966,7 @@ impl RObject for TdType {
         Self::DatabaseStatistics(value) => value.extra(),
         Self::DeepLinkInfo(value) => value.extra(),
         Self::EmailAddressAuthenticationCodeInfo(value) => value.extra(),
+        Self::Emojis(value) => value.extra(),
         Self::Error(value) => value.extra(),
         Self::File(value) => value.extra(),
         Self::FilePart(value) => value.extra(),
@@ -953,6 +983,7 @@ impl RObject for TdType {
         Self::LogTags(value) => value.extra(),
         Self::LogVerbosityLevel(value) => value.extra(),
         Self::Message(value) => value.extra(),
+        Self::MessageLinkInfo(value) => value.extra(),
         Self::Messages(value) => value.extra(),
         Self::NetworkStatistics(value) => value.extra(),
         Self::Ok(value) => value.extra(),
@@ -973,7 +1004,6 @@ impl RObject for TdType {
         Self::Seconds(value) => value.extra(),
         Self::SecretChat(value) => value.extra(),
         Self::Sessions(value) => value.extra(),
-        Self::StickerEmojis(value) => value.extra(),
         Self::StickerSet(value) => value.extra(),
         Self::StickerSets(value) => value.extra(),
         Self::Stickers(value) => value.extra(),
@@ -999,7 +1029,6 @@ impl RObject for TdType {
         Self::UserProfilePhotos(value) => value.extra(),
         Self::Users(value) => value.extra(),
         Self::ValidatedOrderInfo(value) => value.extra(),
-        Self::Wallpapers(value) => value.extra(),
         Self::WebPage(value) => value.extra(),
         Self::WebPageInstantView(value) => value.extra(),
       
@@ -1023,6 +1052,7 @@ impl RObject for TdType {
         Self::UpdateChatNotificationSettings(value) => value.to_json(),
         Self::UpdateChatOnlineMemberCount(value) => value.to_json(),
         Self::UpdateChatOrder(value) => value.to_json(),
+        Self::UpdateChatPermissions(value) => value.to_json(),
         Self::UpdateChatPhoto(value) => value.to_json(),
         Self::UpdateChatPinnedMessage(value) => value.to_json(),
         Self::UpdateChatReadInbox(value) => value.to_json(),
@@ -1065,6 +1095,7 @@ impl RObject for TdType {
         Self::UpdateSavedAnimations(value) => value.to_json(),
         Self::UpdateScopeNotificationSettings(value) => value.to_json(),
         Self::UpdateSecretChat(value) => value.to_json(),
+        Self::UpdateSelectedBackground(value) => value.to_json(),
         Self::UpdateServiceNotification(value) => value.to_json(),
         Self::UpdateSupergroup(value) => value.to_json(),
         Self::UpdateSupergroupFullInfo(value) => value.to_json(),
@@ -1089,6 +1120,9 @@ impl RObject for TdType {
         Self::AccountTtl(value) => value.to_json(),
         Self::Animations(value) => value.to_json(),
         Self::AuthenticationCodeInfo(value) => value.to_json(),
+        Self::AutoDownloadSettingsPresets(value) => value.to_json(),
+        Self::Background(value) => value.to_json(),
+        Self::Backgrounds(value) => value.to_json(),
         Self::BasicGroup(value) => value.to_json(),
         Self::BasicGroupFullInfo(value) => value.to_json(),
         Self::CallId(value) => value.to_json(),
@@ -1107,6 +1141,7 @@ impl RObject for TdType {
         Self::DatabaseStatistics(value) => value.to_json(),
         Self::DeepLinkInfo(value) => value.to_json(),
         Self::EmailAddressAuthenticationCodeInfo(value) => value.to_json(),
+        Self::Emojis(value) => value.to_json(),
         Self::Error(value) => value.to_json(),
         Self::File(value) => value.to_json(),
         Self::FilePart(value) => value.to_json(),
@@ -1123,6 +1158,7 @@ impl RObject for TdType {
         Self::LogTags(value) => value.to_json(),
         Self::LogVerbosityLevel(value) => value.to_json(),
         Self::Message(value) => value.to_json(),
+        Self::MessageLinkInfo(value) => value.to_json(),
         Self::Messages(value) => value.to_json(),
         Self::NetworkStatistics(value) => value.to_json(),
         Self::Ok(value) => value.to_json(),
@@ -1143,7 +1179,6 @@ impl RObject for TdType {
         Self::Seconds(value) => value.to_json(),
         Self::SecretChat(value) => value.to_json(),
         Self::Sessions(value) => value.to_json(),
-        Self::StickerEmojis(value) => value.to_json(),
         Self::StickerSet(value) => value.to_json(),
         Self::StickerSets(value) => value.to_json(),
         Self::Stickers(value) => value.to_json(),
@@ -1169,7 +1204,6 @@ impl RObject for TdType {
         Self::UserProfilePhotos(value) => value.to_json(),
         Self::Users(value) => value.to_json(),
         Self::ValidatedOrderInfo(value) => value.to_json(),
-        Self::Wallpapers(value) => value.to_json(),
         Self::WebPage(value) => value.to_json(),
         Self::WebPageInstantView(value) => value.to_json(),
       
