@@ -27,7 +27,7 @@ pub enum AuthorizationState {
   LoggingOut(AuthorizationStateLoggingOut),
   /// The user has been successfully authorized. TDLib is now ready to answer queries
   Ready(AuthorizationStateReady),
-  /// TDLib needs the user's authentication code to finalize authorization
+  /// TDLib needs the user's authentication code to authorize
   WaitCode(AuthorizationStateWaitCode),
   /// TDLib needs an encryption key to decrypt the local database
   WaitEncryptionKey(AuthorizationStateWaitEncryptionKey),
@@ -35,6 +35,8 @@ pub enum AuthorizationState {
   WaitPassword(AuthorizationStateWaitPassword),
   /// TDLib needs the user's phone number to authorize
   WaitPhoneNumber(AuthorizationStateWaitPhoneNumber),
+  /// The user is unregistered and need to accept terms of service and enter their first name and last name to finish registration
+  WaitRegistration(AuthorizationStateWaitRegistration),
   /// TDLib needs TdlibParameters for initialization
   WaitTdlibParameters(AuthorizationStateWaitTdlibParameters),
   /// Returns the current authorization state; this is an offline request. For informational purposes only. Use updateAuthorizationState instead to maintain the current authorization state
@@ -59,6 +61,7 @@ impl<'de> Deserialize<'de> for AuthorizationState {
       (authorizationStateWaitEncryptionKey, WaitEncryptionKey);
       (authorizationStateWaitPassword, WaitPassword);
       (authorizationStateWaitPhoneNumber, WaitPhoneNumber);
+      (authorizationStateWaitRegistration, WaitRegistration);
       (authorizationStateWaitTdlibParameters, WaitTdlibParameters);
       (getAuthorizationState, GetAuthorizationState);
 
@@ -77,6 +80,7 @@ impl RObject for AuthorizationState {
       AuthorizationState::WaitEncryptionKey(t) => t.td_name(),
       AuthorizationState::WaitPassword(t) => t.td_name(),
       AuthorizationState::WaitPhoneNumber(t) => t.td_name(),
+      AuthorizationState::WaitRegistration(t) => t.td_name(),
       AuthorizationState::WaitTdlibParameters(t) => t.td_name(),
       AuthorizationState::GetAuthorizationState(t) => t.td_name(),
 
@@ -93,6 +97,7 @@ impl RObject for AuthorizationState {
       AuthorizationState::WaitEncryptionKey(t) => t.extra(),
       AuthorizationState::WaitPassword(t) => t.extra(),
       AuthorizationState::WaitPhoneNumber(t) => t.extra(),
+      AuthorizationState::WaitRegistration(t) => t.extra(),
       AuthorizationState::WaitTdlibParameters(t) => t.extra(),
       AuthorizationState::GetAuthorizationState(t) => t.extra(),
 
@@ -114,6 +119,7 @@ impl AuthorizationState {
   pub fn is_wait_encryption_key(&self) -> bool { if let AuthorizationState::WaitEncryptionKey(_) = self { true } else { false } }
   pub fn is_wait_password(&self) -> bool { if let AuthorizationState::WaitPassword(_) = self { true } else { false } }
   pub fn is_wait_phone_number(&self) -> bool { if let AuthorizationState::WaitPhoneNumber(_) = self { true } else { false } }
+  pub fn is_wait_registration(&self) -> bool { if let AuthorizationState::WaitRegistration(_) = self { true } else { false } }
   pub fn is_wait_tdlib_parameters(&self) -> bool { if let AuthorizationState::WaitTdlibParameters(_) = self { true } else { false } }
   pub fn is_get_authorization_state(&self) -> bool { if let AuthorizationState::GetAuthorizationState(_) = self { true } else { false } }
 
@@ -125,6 +131,7 @@ impl AuthorizationState {
   pub fn on_wait_encryption_key<F: FnOnce(&AuthorizationStateWaitEncryptionKey)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitEncryptionKey(t) = self { fnc(t) }; self }
   pub fn on_wait_password<F: FnOnce(&AuthorizationStateWaitPassword)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitPassword(t) = self { fnc(t) }; self }
   pub fn on_wait_phone_number<F: FnOnce(&AuthorizationStateWaitPhoneNumber)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitPhoneNumber(t) = self { fnc(t) }; self }
+  pub fn on_wait_registration<F: FnOnce(&AuthorizationStateWaitRegistration)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitRegistration(t) = self { fnc(t) }; self }
   pub fn on_wait_tdlib_parameters<F: FnOnce(&AuthorizationStateWaitTdlibParameters)>(&self, fnc: F) -> &Self { if let AuthorizationState::WaitTdlibParameters(t) = self { fnc(t) }; self }
   pub fn on_get_authorization_state<F: FnOnce(&GetAuthorizationState)>(&self, fnc: F) -> &Self { if let AuthorizationState::GetAuthorizationState(t) = self { fnc(t) }; self }
 
@@ -136,6 +143,7 @@ impl AuthorizationState {
   pub fn as_wait_encryption_key(&self) -> Option<&AuthorizationStateWaitEncryptionKey> { if let AuthorizationState::WaitEncryptionKey(t) = self { return Some(t) } None }
   pub fn as_wait_password(&self) -> Option<&AuthorizationStateWaitPassword> { if let AuthorizationState::WaitPassword(t) = self { return Some(t) } None }
   pub fn as_wait_phone_number(&self) -> Option<&AuthorizationStateWaitPhoneNumber> { if let AuthorizationState::WaitPhoneNumber(t) = self { return Some(t) } None }
+  pub fn as_wait_registration(&self) -> Option<&AuthorizationStateWaitRegistration> { if let AuthorizationState::WaitRegistration(t) = self { return Some(t) } None }
   pub fn as_wait_tdlib_parameters(&self) -> Option<&AuthorizationStateWaitTdlibParameters> { if let AuthorizationState::WaitTdlibParameters(t) = self { return Some(t) } None }
   pub fn as_get_authorization_state(&self) -> Option<&GetAuthorizationState> { if let AuthorizationState::GetAuthorizationState(t) = self { return Some(t) } None }
 
@@ -157,6 +165,8 @@ impl AuthorizationState {
 
   pub fn wait_phone_number<T: AsRef<AuthorizationStateWaitPhoneNumber>>(t: T) -> Self { AuthorizationState::WaitPhoneNumber(t.as_ref().clone()) }
 
+  pub fn wait_registration<T: AsRef<AuthorizationStateWaitRegistration>>(t: T) -> Self { AuthorizationState::WaitRegistration(t.as_ref().clone()) }
+
   pub fn wait_tdlib_parameters<T: AsRef<AuthorizationStateWaitTdlibParameters>>(t: T) -> Self { AuthorizationState::WaitTdlibParameters(t.as_ref().clone()) }
 
   pub fn get_authorization_state<T: AsRef<GetAuthorizationState>>(t: T) -> Self { AuthorizationState::GetAuthorizationState(t.as_ref().clone()) }
@@ -405,7 +415,7 @@ impl AsRef<AuthorizationStateReady> for RTDAuthorizationStateReadyBuilder {
 
 
 
-/// TDLib needs the user's authentication code to finalize authorization
+/// TDLib needs the user's authentication code to authorize
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateWaitCode {
   #[doc(hidden)]
@@ -414,10 +424,6 @@ pub struct AuthorizationStateWaitCode {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// True, if the user is already registered
-  is_registered: bool,
-  /// Telegram terms of service, which should be accepted before user can continue registration; may be null
-  terms_of_service: Option<TermsOfService>,
   /// Information about the authorization code that was sent
   code_info: AuthenticationCodeInfo,
   
@@ -443,10 +449,6 @@ impl AuthorizationStateWaitCode {
     RTDAuthorizationStateWaitCodeBuilder { inner }
   }
 
-  pub fn is_registered(&self) -> bool { self.is_registered }
-
-  pub fn terms_of_service(&self) -> &Option<TermsOfService> { &self.terms_of_service }
-
   pub fn code_info(&self) -> &AuthenticationCodeInfo { &self.code_info }
 
 }
@@ -460,18 +462,6 @@ impl RTDAuthorizationStateWaitCodeBuilder {
   pub fn build(&self) -> AuthorizationStateWaitCode { self.inner.clone() }
 
    
-  pub fn is_registered(&mut self, is_registered: bool) -> &mut Self {
-    self.inner.is_registered = is_registered;
-    self
-  }
-
-   
-  pub fn terms_of_service<T: AsRef<TermsOfService>>(&mut self, terms_of_service: T) -> &mut Self {
-    self.inner.terms_of_service = Some(terms_of_service.as_ref().clone());
-    self
-  }
-
-   
   pub fn code_info<T: AsRef<AuthenticationCodeInfo>>(&mut self, code_info: T) -> &mut Self {
     self.inner.code_info = code_info.as_ref().clone();
     self
@@ -572,7 +562,7 @@ pub struct AuthorizationStateWaitPassword {
   extra: Option<String>,
   /// Hint for the password; may be empty
   password_hint: String,
-  /// True if a recovery email address has been set up
+  /// True, if a recovery email address has been set up
   has_recovery_email_address: bool,
   /// Pattern of the email address to which the recovery email was sent; empty until a recovery email has been sent
   recovery_email_address_pattern: String,
@@ -707,6 +697,74 @@ impl AsRef<AuthorizationStateWaitPhoneNumber> for RTDAuthorizationStateWaitPhone
 
 
 
+/// The user is unregistered and need to accept terms of service and enter their first name and last name to finish registration
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct AuthorizationStateWaitRegistration {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Telegram terms of service
+  terms_of_service: TermsOfService,
+  
+}
+
+impl RObject for AuthorizationStateWaitRegistration {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "authorizationStateWaitRegistration" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDAuthorizationState for AuthorizationStateWaitRegistration {}
+
+
+
+impl AuthorizationStateWaitRegistration {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDAuthorizationStateWaitRegistrationBuilder {
+    let mut inner = AuthorizationStateWaitRegistration::default();
+    inner.td_name = "authorizationStateWaitRegistration".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDAuthorizationStateWaitRegistrationBuilder { inner }
+  }
+
+  pub fn terms_of_service(&self) -> &TermsOfService { &self.terms_of_service }
+
+}
+
+#[doc(hidden)]
+pub struct RTDAuthorizationStateWaitRegistrationBuilder {
+  inner: AuthorizationStateWaitRegistration
+}
+
+impl RTDAuthorizationStateWaitRegistrationBuilder {
+  pub fn build(&self) -> AuthorizationStateWaitRegistration { self.inner.clone() }
+
+   
+  pub fn terms_of_service<T: AsRef<TermsOfService>>(&mut self, terms_of_service: T) -> &mut Self {
+    self.inner.terms_of_service = terms_of_service.as_ref().clone();
+    self
+  }
+
+}
+
+impl AsRef<AuthorizationStateWaitRegistration> for AuthorizationStateWaitRegistration {
+  fn as_ref(&self) -> &AuthorizationStateWaitRegistration { self }
+}
+
+impl AsRef<AuthorizationStateWaitRegistration> for RTDAuthorizationStateWaitRegistrationBuilder {
+  fn as_ref(&self) -> &AuthorizationStateWaitRegistration { &self.inner }
+}
+
+
+
+
+
+
+
 /// TDLib needs TdlibParameters for initialization
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct AuthorizationStateWaitTdlibParameters {
