@@ -502,6 +502,8 @@ pub struct CallStateReady {
   encryption_key: String,
   /// Encryption key emojis fingerprint
   emojis: Vec<String>,
+  /// True, if peer-to-peer connection is allowed by users privacy settings
+  allow_p2p: bool,
   
 }
 
@@ -535,6 +537,8 @@ impl CallStateReady {
 
   pub fn emojis(&self) -> &Vec<String> { &self.emojis }
 
+  pub fn allow_p2p(&self) -> bool { self.allow_p2p }
+
 }
 
 #[doc(hidden)]
@@ -575,6 +579,12 @@ impl RTDCallStateReadyBuilder {
     self
   }
 
+   
+  pub fn allow_p2p(&mut self, allow_p2p: bool) -> &mut Self {
+    self.inner.allow_p2p = allow_p2p;
+    self
+  }
+
 }
 
 impl AsRef<CallStateReady> for CallStateReady {
