@@ -21,7 +21,7 @@ pub enum ChatEventAction {
   #[doc(hidden)] _Default(()),
   /// The chat description was changed
   ChatEventDescriptionChanged(ChatEventDescriptionChanged),
-  /// The anyone_can_invite setting of a supergroup chat was toggled
+  /// The can_invite_users permission of a supergroup chat was toggled
   ChatEventInvitesToggled(ChatEventInvitesToggled),
   /// The is_all_history_available setting of a supergroup was toggled
   ChatEventIsAllHistoryAvailableToggled(ChatEventIsAllHistoryAvailableToggled),
@@ -43,8 +43,12 @@ pub enum ChatEventAction {
   ChatEventMessagePinned(ChatEventMessagePinned),
   /// A message was unpinned
   ChatEventMessageUnpinned(ChatEventMessageUnpinned),
+  /// The chat permissions was changed
+  ChatEventPermissionsChanged(ChatEventPermissionsChanged),
   /// The chat photo was changed
   ChatEventPhotoChanged(ChatEventPhotoChanged),
+  /// A poll in a message was stopped
+  ChatEventPollStopped(ChatEventPollStopped),
   /// The sign_messages setting of a channel was toggled
   ChatEventSignMessagesToggled(ChatEventSignMessagesToggled),
   /// The supergroup sticker set was changed
@@ -77,7 +81,9 @@ impl<'de> Deserialize<'de> for ChatEventAction {
       (chatEventMessageEdited, ChatEventMessageEdited);
       (chatEventMessagePinned, ChatEventMessagePinned);
       (chatEventMessageUnpinned, ChatEventMessageUnpinned);
+      (chatEventPermissionsChanged, ChatEventPermissionsChanged);
       (chatEventPhotoChanged, ChatEventPhotoChanged);
+      (chatEventPollStopped, ChatEventPollStopped);
       (chatEventSignMessagesToggled, ChatEventSignMessagesToggled);
       (chatEventStickerSetChanged, ChatEventStickerSetChanged);
       (chatEventTitleChanged, ChatEventTitleChanged);
@@ -102,7 +108,9 @@ impl RObject for ChatEventAction {
       ChatEventAction::ChatEventMessageEdited(t) => t.td_name(),
       ChatEventAction::ChatEventMessagePinned(t) => t.td_name(),
       ChatEventAction::ChatEventMessageUnpinned(t) => t.td_name(),
+      ChatEventAction::ChatEventPermissionsChanged(t) => t.td_name(),
       ChatEventAction::ChatEventPhotoChanged(t) => t.td_name(),
+      ChatEventAction::ChatEventPollStopped(t) => t.td_name(),
       ChatEventAction::ChatEventSignMessagesToggled(t) => t.td_name(),
       ChatEventAction::ChatEventStickerSetChanged(t) => t.td_name(),
       ChatEventAction::ChatEventTitleChanged(t) => t.td_name(),
@@ -125,7 +133,9 @@ impl RObject for ChatEventAction {
       ChatEventAction::ChatEventMessageEdited(t) => t.extra(),
       ChatEventAction::ChatEventMessagePinned(t) => t.extra(),
       ChatEventAction::ChatEventMessageUnpinned(t) => t.extra(),
+      ChatEventAction::ChatEventPermissionsChanged(t) => t.extra(),
       ChatEventAction::ChatEventPhotoChanged(t) => t.extra(),
+      ChatEventAction::ChatEventPollStopped(t) => t.extra(),
       ChatEventAction::ChatEventSignMessagesToggled(t) => t.extra(),
       ChatEventAction::ChatEventStickerSetChanged(t) => t.extra(),
       ChatEventAction::ChatEventTitleChanged(t) => t.extra(),
@@ -153,7 +163,9 @@ impl ChatEventAction {
   pub fn is_chat_event_message_edited(&self) -> bool { if let ChatEventAction::ChatEventMessageEdited(_) = self { true } else { false } }
   pub fn is_chat_event_message_pinned(&self) -> bool { if let ChatEventAction::ChatEventMessagePinned(_) = self { true } else { false } }
   pub fn is_chat_event_message_unpinned(&self) -> bool { if let ChatEventAction::ChatEventMessageUnpinned(_) = self { true } else { false } }
+  pub fn is_chat_event_permissions_changed(&self) -> bool { if let ChatEventAction::ChatEventPermissionsChanged(_) = self { true } else { false } }
   pub fn is_chat_event_photo_changed(&self) -> bool { if let ChatEventAction::ChatEventPhotoChanged(_) = self { true } else { false } }
+  pub fn is_chat_event_poll_stopped(&self) -> bool { if let ChatEventAction::ChatEventPollStopped(_) = self { true } else { false } }
   pub fn is_chat_event_sign_messages_toggled(&self) -> bool { if let ChatEventAction::ChatEventSignMessagesToggled(_) = self { true } else { false } }
   pub fn is_chat_event_sticker_set_changed(&self) -> bool { if let ChatEventAction::ChatEventStickerSetChanged(_) = self { true } else { false } }
   pub fn is_chat_event_title_changed(&self) -> bool { if let ChatEventAction::ChatEventTitleChanged(_) = self { true } else { false } }
@@ -171,7 +183,9 @@ impl ChatEventAction {
   pub fn on_chat_event_message_edited<F: FnOnce(&ChatEventMessageEdited)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventMessageEdited(t) = self { fnc(t) }; self }
   pub fn on_chat_event_message_pinned<F: FnOnce(&ChatEventMessagePinned)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventMessagePinned(t) = self { fnc(t) }; self }
   pub fn on_chat_event_message_unpinned<F: FnOnce(&ChatEventMessageUnpinned)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventMessageUnpinned(t) = self { fnc(t) }; self }
+  pub fn on_chat_event_permissions_changed<F: FnOnce(&ChatEventPermissionsChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventPermissionsChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_photo_changed<F: FnOnce(&ChatEventPhotoChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventPhotoChanged(t) = self { fnc(t) }; self }
+  pub fn on_chat_event_poll_stopped<F: FnOnce(&ChatEventPollStopped)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventPollStopped(t) = self { fnc(t) }; self }
   pub fn on_chat_event_sign_messages_toggled<F: FnOnce(&ChatEventSignMessagesToggled)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventSignMessagesToggled(t) = self { fnc(t) }; self }
   pub fn on_chat_event_sticker_set_changed<F: FnOnce(&ChatEventStickerSetChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventStickerSetChanged(t) = self { fnc(t) }; self }
   pub fn on_chat_event_title_changed<F: FnOnce(&ChatEventTitleChanged)>(&self, fnc: F) -> &Self { if let ChatEventAction::ChatEventTitleChanged(t) = self { fnc(t) }; self }
@@ -189,7 +203,9 @@ impl ChatEventAction {
   pub fn as_chat_event_message_edited(&self) -> Option<&ChatEventMessageEdited> { if let ChatEventAction::ChatEventMessageEdited(t) = self { return Some(t) } None }
   pub fn as_chat_event_message_pinned(&self) -> Option<&ChatEventMessagePinned> { if let ChatEventAction::ChatEventMessagePinned(t) = self { return Some(t) } None }
   pub fn as_chat_event_message_unpinned(&self) -> Option<&ChatEventMessageUnpinned> { if let ChatEventAction::ChatEventMessageUnpinned(t) = self { return Some(t) } None }
+  pub fn as_chat_event_permissions_changed(&self) -> Option<&ChatEventPermissionsChanged> { if let ChatEventAction::ChatEventPermissionsChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_photo_changed(&self) -> Option<&ChatEventPhotoChanged> { if let ChatEventAction::ChatEventPhotoChanged(t) = self { return Some(t) } None }
+  pub fn as_chat_event_poll_stopped(&self) -> Option<&ChatEventPollStopped> { if let ChatEventAction::ChatEventPollStopped(t) = self { return Some(t) } None }
   pub fn as_chat_event_sign_messages_toggled(&self) -> Option<&ChatEventSignMessagesToggled> { if let ChatEventAction::ChatEventSignMessagesToggled(t) = self { return Some(t) } None }
   pub fn as_chat_event_sticker_set_changed(&self) -> Option<&ChatEventStickerSetChanged> { if let ChatEventAction::ChatEventStickerSetChanged(t) = self { return Some(t) } None }
   pub fn as_chat_event_title_changed(&self) -> Option<&ChatEventTitleChanged> { if let ChatEventAction::ChatEventTitleChanged(t) = self { return Some(t) } None }
@@ -221,8 +237,12 @@ impl ChatEventAction {
 
   pub fn chat_event_message_unpinned<T: AsRef<ChatEventMessageUnpinned>>(t: T) -> Self { ChatEventAction::ChatEventMessageUnpinned(t.as_ref().clone()) }
 
+  pub fn chat_event_permissions_changed<T: AsRef<ChatEventPermissionsChanged>>(t: T) -> Self { ChatEventAction::ChatEventPermissionsChanged(t.as_ref().clone()) }
+
   pub fn chat_event_photo_changed<T: AsRef<ChatEventPhotoChanged>>(t: T) -> Self { ChatEventAction::ChatEventPhotoChanged(t.as_ref().clone()) }
 
+  pub fn chat_event_poll_stopped<T: AsRef<ChatEventPollStopped>>(t: T) -> Self { ChatEventAction::ChatEventPollStopped(t.as_ref().clone()) }
+
   pub fn chat_event_sign_messages_toggled<T: AsRef<ChatEventSignMessagesToggled>>(t: T) -> Self { ChatEventAction::ChatEventSignMessagesToggled(t.as_ref().clone()) }
 
   pub fn chat_event_sticker_set_changed<T: AsRef<ChatEventStickerSetChanged>>(t: T) -> Self { ChatEventAction::ChatEventStickerSetChanged(t.as_ref().clone()) }
@@ -321,7 +341,7 @@ impl AsRef<ChatEventDescriptionChanged> for RTDChatEventDescriptionChangedBuilde
 
 
 
-/// The anyone_can_invite setting of a supergroup chat was toggled
+/// The can_invite_users permission of a supergroup chat was toggled
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatEventInvitesToggled {
   #[doc(hidden)]
@@ -330,8 +350,8 @@ pub struct ChatEventInvitesToggled {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// New value of anyone_can_invite
-  anyone_can_invite: bool,
+  /// New value of can_invite_users permission
+  can_invite_users: bool,
   
 }
 
@@ -355,7 +375,7 @@ impl ChatEventInvitesToggled {
     RTDChatEventInvitesToggledBuilder { inner }
   }
 
-  pub fn anyone_can_invite(&self) -> bool { self.anyone_can_invite }
+  pub fn can_invite_users(&self) -> bool { self.can_invite_users }
 
 }
 
@@ -368,8 +388,8 @@ impl RTDChatEventInvitesToggledBuilder {
   pub fn build(&self) -> ChatEventInvitesToggled { self.inner.clone() }
 
    
-  pub fn anyone_can_invite(&mut self, anyone_can_invite: bool) -> &mut Self {
-    self.inner.anyone_can_invite = anyone_can_invite;
+  pub fn can_invite_users(&mut self, can_invite_users: bool) -> &mut Self {
+    self.inner.can_invite_users = can_invite_users;
     self
   }
 
@@ -1099,6 +1119,84 @@ impl AsRef<ChatEventMessageUnpinned> for RTDChatEventMessageUnpinnedBuilder {
 
 
 
+/// The chat permissions was changed
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatEventPermissionsChanged {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Previous chat permissions
+  old_permissions: ChatPermissions,
+  /// New chat permissions
+  new_permissions: ChatPermissions,
+  
+}
+
+impl RObject for ChatEventPermissionsChanged {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatEventPermissionsChanged" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatEventAction for ChatEventPermissionsChanged {}
+
+
+
+impl ChatEventPermissionsChanged {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatEventPermissionsChangedBuilder {
+    let mut inner = ChatEventPermissionsChanged::default();
+    inner.td_name = "chatEventPermissionsChanged".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatEventPermissionsChangedBuilder { inner }
+  }
+
+  pub fn old_permissions(&self) -> &ChatPermissions { &self.old_permissions }
+
+  pub fn new_permissions(&self) -> &ChatPermissions { &self.new_permissions }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatEventPermissionsChangedBuilder {
+  inner: ChatEventPermissionsChanged
+}
+
+impl RTDChatEventPermissionsChangedBuilder {
+  pub fn build(&self) -> ChatEventPermissionsChanged { self.inner.clone() }
+
+   
+  pub fn old_permissions<T: AsRef<ChatPermissions>>(&mut self, old_permissions: T) -> &mut Self {
+    self.inner.old_permissions = old_permissions.as_ref().clone();
+    self
+  }
+
+   
+  pub fn new_permissions<T: AsRef<ChatPermissions>>(&mut self, new_permissions: T) -> &mut Self {
+    self.inner.new_permissions = new_permissions.as_ref().clone();
+    self
+  }
+
+}
+
+impl AsRef<ChatEventPermissionsChanged> for ChatEventPermissionsChanged {
+  fn as_ref(&self) -> &ChatEventPermissionsChanged { self }
+}
+
+impl AsRef<ChatEventPermissionsChanged> for RTDChatEventPermissionsChangedBuilder {
+  fn as_ref(&self) -> &ChatEventPermissionsChanged { &self.inner }
+}
+
+
+
+
+
+
+
 /// The chat photo was changed
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatEventPhotoChanged {
@@ -1109,9 +1207,9 @@ pub struct ChatEventPhotoChanged {
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
   /// Previous chat photo value; may be null
-  old_photo: Option<ChatPhoto>,
+  old_photo: Option<Photo>,
   /// New chat photo value; may be null
-  new_photo: Option<ChatPhoto>,
+  new_photo: Option<Photo>,
   
 }
 
@@ -1135,9 +1233,9 @@ impl ChatEventPhotoChanged {
     RTDChatEventPhotoChangedBuilder { inner }
   }
 
-  pub fn old_photo(&self) -> &Option<ChatPhoto> { &self.old_photo }
+  pub fn old_photo(&self) -> &Option<Photo> { &self.old_photo }
 
-  pub fn new_photo(&self) -> &Option<ChatPhoto> { &self.new_photo }
+  pub fn new_photo(&self) -> &Option<Photo> { &self.new_photo }
 
 }
 
@@ -1150,13 +1248,13 @@ impl RTDChatEventPhotoChangedBuilder {
   pub fn build(&self) -> ChatEventPhotoChanged { self.inner.clone() }
 
    
-  pub fn old_photo<T: AsRef<ChatPhoto>>(&mut self, old_photo: T) -> &mut Self {
+  pub fn old_photo<T: AsRef<Photo>>(&mut self, old_photo: T) -> &mut Self {
     self.inner.old_photo = Some(old_photo.as_ref().clone());
     self
   }
 
    
-  pub fn new_photo<T: AsRef<ChatPhoto>>(&mut self, new_photo: T) -> &mut Self {
+  pub fn new_photo<T: AsRef<Photo>>(&mut self, new_photo: T) -> &mut Self {
     self.inner.new_photo = Some(new_photo.as_ref().clone());
     self
   }
@@ -1177,6 +1275,74 @@ impl AsRef<ChatEventPhotoChanged> for RTDChatEventPhotoChangedBuilder {
 
 
 
+/// A poll in a message was stopped
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatEventPollStopped {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// The message with the poll
+  message: Message,
+  
+}
+
+impl RObject for ChatEventPollStopped {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatEventPollStopped" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatEventAction for ChatEventPollStopped {}
+
+
+
+impl ChatEventPollStopped {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatEventPollStoppedBuilder {
+    let mut inner = ChatEventPollStopped::default();
+    inner.td_name = "chatEventPollStopped".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatEventPollStoppedBuilder { inner }
+  }
+
+  pub fn message(&self) -> &Message { &self.message }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatEventPollStoppedBuilder {
+  inner: ChatEventPollStopped
+}
+
+impl RTDChatEventPollStoppedBuilder {
+  pub fn build(&self) -> ChatEventPollStopped { self.inner.clone() }
+
+   
+  pub fn message<T: AsRef<Message>>(&mut self, message: T) -> &mut Self {
+    self.inner.message = message.as_ref().clone();
+    self
+  }
+
+}
+
+impl AsRef<ChatEventPollStopped> for ChatEventPollStopped {
+  fn as_ref(&self) -> &ChatEventPollStopped { self }
+}
+
+impl AsRef<ChatEventPollStopped> for RTDChatEventPollStoppedBuilder {
+  fn as_ref(&self) -> &ChatEventPollStopped { &self.inner }
+}
+
+
+
+
+
+
+
 /// The sign_messages setting of a channel was toggled
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatEventSignMessagesToggled {
