@@ -25,6 +25,8 @@ pub enum ChatMembersFilter {
   Banned(ChatMembersFilterBanned),
   /// Returns bot members of the chat
   Bots(ChatMembersFilterBots),
+  /// Returns contacts of the user
+  Contacts(ChatMembersFilterContacts),
   /// Returns all chat members, including restricted chat members
   Members(ChatMembersFilterMembers),
   /// Returns users under certain restrictions in the chat; can be used only by administrators in a supergroup
@@ -44,6 +46,7 @@ impl<'de> Deserialize<'de> for ChatMembersFilter {
       (chatMembersFilterAdministrators, Administrators);
       (chatMembersFilterBanned, Banned);
       (chatMembersFilterBots, Bots);
+      (chatMembersFilterContacts, Contacts);
       (chatMembersFilterMembers, Members);
       (chatMembersFilterRestricted, Restricted);
 
@@ -57,6 +60,7 @@ impl RObject for ChatMembersFilter {
       ChatMembersFilter::Administrators(t) => t.td_name(),
       ChatMembersFilter::Banned(t) => t.td_name(),
       ChatMembersFilter::Bots(t) => t.td_name(),
+      ChatMembersFilter::Contacts(t) => t.td_name(),
       ChatMembersFilter::Members(t) => t.td_name(),
       ChatMembersFilter::Restricted(t) => t.td_name(),
 
@@ -68,6 +72,7 @@ impl RObject for ChatMembersFilter {
       ChatMembersFilter::Administrators(t) => t.extra(),
       ChatMembersFilter::Banned(t) => t.extra(),
       ChatMembersFilter::Bots(t) => t.extra(),
+      ChatMembersFilter::Contacts(t) => t.extra(),
       ChatMembersFilter::Members(t) => t.extra(),
       ChatMembersFilter::Restricted(t) => t.extra(),
 
@@ -84,18 +89,21 @@ impl ChatMembersFilter {
   pub fn is_administrators(&self) -> bool { if let ChatMembersFilter::Administrators(_) = self { true } else { false } }
   pub fn is_banned(&self) -> bool { if let ChatMembersFilter::Banned(_) = self { true } else { false } }
   pub fn is_bots(&self) -> bool { if let ChatMembersFilter::Bots(_) = self { true } else { false } }
+  pub fn is_contacts(&self) -> bool { if let ChatMembersFilter::Contacts(_) = self { true } else { false } }
   pub fn is_members(&self) -> bool { if let ChatMembersFilter::Members(_) = self { true } else { false } }
   pub fn is_restricted(&self) -> bool { if let ChatMembersFilter::Restricted(_) = self { true } else { false } }
 
   pub fn on_administrators<F: FnOnce(&ChatMembersFilterAdministrators)>(&self, fnc: F) -> &Self { if let ChatMembersFilter::Administrators(t) = self { fnc(t) }; self }
   pub fn on_banned<F: FnOnce(&ChatMembersFilterBanned)>(&self, fnc: F) -> &Self { if let ChatMembersFilter::Banned(t) = self { fnc(t) }; self }
   pub fn on_bots<F: FnOnce(&ChatMembersFilterBots)>(&self, fnc: F) -> &Self { if let ChatMembersFilter::Bots(t) = self { fnc(t) }; self }
+  pub fn on_contacts<F: FnOnce(&ChatMembersFilterContacts)>(&self, fnc: F) -> &Self { if let ChatMembersFilter::Contacts(t) = self { fnc(t) }; self }
   pub fn on_members<F: FnOnce(&ChatMembersFilterMembers)>(&self, fnc: F) -> &Self { if let ChatMembersFilter::Members(t) = self { fnc(t) }; self }
   pub fn on_restricted<F: FnOnce(&ChatMembersFilterRestricted)>(&self, fnc: F) -> &Self { if let ChatMembersFilter::Restricted(t) = self { fnc(t) }; self }
 
   pub fn as_administrators(&self) -> Option<&ChatMembersFilterAdministrators> { if let ChatMembersFilter::Administrators(t) = self { return Some(t) } None }
   pub fn as_banned(&self) -> Option<&ChatMembersFilterBanned> { if let ChatMembersFilter::Banned(t) = self { return Some(t) } None }
   pub fn as_bots(&self) -> Option<&ChatMembersFilterBots> { if let ChatMembersFilter::Bots(t) = self { return Some(t) } None }
+  pub fn as_contacts(&self) -> Option<&ChatMembersFilterContacts> { if let ChatMembersFilter::Contacts(t) = self { return Some(t) } None }
   pub fn as_members(&self) -> Option<&ChatMembersFilterMembers> { if let ChatMembersFilter::Members(t) = self { return Some(t) } None }
   pub fn as_restricted(&self) -> Option<&ChatMembersFilterRestricted> { if let ChatMembersFilter::Restricted(t) = self { return Some(t) } None }
 
@@ -107,6 +115,8 @@ impl ChatMembersFilter {
 
   pub fn bots<T: AsRef<ChatMembersFilterBots>>(t: T) -> Self { ChatMembersFilter::Bots(t.as_ref().clone()) }
 
+  pub fn contacts<T: AsRef<ChatMembersFilterContacts>>(t: T) -> Self { ChatMembersFilter::Contacts(t.as_ref().clone()) }
+
   pub fn members<T: AsRef<ChatMembersFilterMembers>>(t: T) -> Self { ChatMembersFilter::Members(t.as_ref().clone()) }
 
   pub fn restricted<T: AsRef<ChatMembersFilterRestricted>>(t: T) -> Self { ChatMembersFilter::Restricted(t.as_ref().clone()) }
@@ -297,6 +307,64 @@ impl AsRef<ChatMembersFilterBots> for RTDChatMembersFilterBotsBuilder {
 
 
 
+/// Returns contacts of the user
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatMembersFilterContacts {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  
+}
+
+impl RObject for ChatMembersFilterContacts {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatMembersFilterContacts" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatMembersFilter for ChatMembersFilterContacts {}
+
+
+
+impl ChatMembersFilterContacts {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatMembersFilterContactsBuilder {
+    let mut inner = ChatMembersFilterContacts::default();
+    inner.td_name = "chatMembersFilterContacts".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatMembersFilterContactsBuilder { inner }
+  }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatMembersFilterContactsBuilder {
+  inner: ChatMembersFilterContacts
+}
+
+impl RTDChatMembersFilterContactsBuilder {
+  pub fn build(&self) -> ChatMembersFilterContacts { self.inner.clone() }
+
+}
+
+impl AsRef<ChatMembersFilterContacts> for ChatMembersFilterContacts {
+  fn as_ref(&self) -> &ChatMembersFilterContacts { self }
+}
+
+impl AsRef<ChatMembersFilterContacts> for RTDChatMembersFilterContactsBuilder {
+  fn as_ref(&self) -> &ChatMembersFilterContacts { &self.inner }
+}
+
+
+
+
+
+
+
 /// Returns all chat members, including restricted chat members
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatMembersFilterMembers {
