@@ -19,7 +19,9 @@ pub struct Document {
   file_name: String,
   /// MIME type of the file; as defined by the sender
   mime_type: String,
-  /// Document thumbnail; as defined by the sender; may be null
+  /// Document minithumbnail; may be null
+  minithumbnail: Option<Minithumbnail>,
+  /// Document thumbnail in JPEG or PNG format (PNG will be used only for background patterns); as defined by the sender; may be null
   thumbnail: Option<PhotoSize>,
   /// File containing the document
   document: File,
@@ -47,6 +49,8 @@ impl Document {
 
   pub fn mime_type(&self) -> &String { &self.mime_type }
 
+  pub fn minithumbnail(&self) -> &Option<Minithumbnail> { &self.minithumbnail }
+
   pub fn thumbnail(&self) -> &Option<PhotoSize> { &self.thumbnail }
 
   pub fn document(&self) -> &File { &self.document }
@@ -74,6 +78,12 @@ impl RTDDocumentBuilder {
   }
 
    
+  pub fn minithumbnail<T: AsRef<Minithumbnail>>(&mut self, minithumbnail: T) -> &mut Self {
+    self.inner.minithumbnail = Some(minithumbnail.as_ref().clone());
+    self
+  }
+
+   
   pub fn thumbnail<T: AsRef<PhotoSize>>(&mut self, thumbnail: T) -> &mut Self {
     self.inner.thumbnail = Some(thumbnail.as_ref().clone());
     self
