@@ -25,6 +25,8 @@ pub enum InlineKeyboardButtonType {
   Callback(InlineKeyboardButtonTypeCallback),
   /// A button with a game that sends a special callback query to a bot. This button must be in the first column and row of the keyboard and can be attached only to a message with content of the type messageGame
   CallbackGame(InlineKeyboardButtonTypeCallbackGame),
+  /// A button that opens a specified URL and automatically logs in in current user if they allowed to do that
+  LoginUrl(InlineKeyboardButtonTypeLoginUrl),
   /// A button that forces an inline query to the bot to be inserted in the input field
   SwitchInline(InlineKeyboardButtonTypeSwitchInline),
   /// A button that opens a specified URL
@@ -44,6 +46,7 @@ impl<'de> Deserialize<'de> for InlineKeyboardButtonType {
       (inlineKeyboardButtonTypeBuy, Buy);
       (inlineKeyboardButtonTypeCallback, Callback);
       (inlineKeyboardButtonTypeCallbackGame, CallbackGame);
+      (inlineKeyboardButtonTypeLoginUrl, LoginUrl);
       (inlineKeyboardButtonTypeSwitchInline, SwitchInline);
       (inlineKeyboardButtonTypeUrl, Url);
 
@@ -57,6 +60,7 @@ impl RObject for InlineKeyboardButtonType {
       InlineKeyboardButtonType::Buy(t) => t.td_name(),
       InlineKeyboardButtonType::Callback(t) => t.td_name(),
       InlineKeyboardButtonType::CallbackGame(t) => t.td_name(),
+      InlineKeyboardButtonType::LoginUrl(t) => t.td_name(),
       InlineKeyboardButtonType::SwitchInline(t) => t.td_name(),
       InlineKeyboardButtonType::Url(t) => t.td_name(),
 
@@ -68,6 +72,7 @@ impl RObject for InlineKeyboardButtonType {
       InlineKeyboardButtonType::Buy(t) => t.extra(),
       InlineKeyboardButtonType::Callback(t) => t.extra(),
       InlineKeyboardButtonType::CallbackGame(t) => t.extra(),
+      InlineKeyboardButtonType::LoginUrl(t) => t.extra(),
       InlineKeyboardButtonType::SwitchInline(t) => t.extra(),
       InlineKeyboardButtonType::Url(t) => t.extra(),
 
@@ -84,18 +89,21 @@ impl InlineKeyboardButtonType {
   pub fn is_buy(&self) -> bool { if let InlineKeyboardButtonType::Buy(_) = self { true } else { false } }
   pub fn is_callback(&self) -> bool { if let InlineKeyboardButtonType::Callback(_) = self { true } else { false } }
   pub fn is_callback_game(&self) -> bool { if let InlineKeyboardButtonType::CallbackGame(_) = self { true } else { false } }
+  pub fn is_login_url(&self) -> bool { if let InlineKeyboardButtonType::LoginUrl(_) = self { true } else { false } }
   pub fn is_switch_inline(&self) -> bool { if let InlineKeyboardButtonType::SwitchInline(_) = self { true } else { false } }
   pub fn is_url(&self) -> bool { if let InlineKeyboardButtonType::Url(_) = self { true } else { false } }
 
   pub fn on_buy<F: FnOnce(&InlineKeyboardButtonTypeBuy)>(&self, fnc: F) -> &Self { if let InlineKeyboardButtonType::Buy(t) = self { fnc(t) }; self }
   pub fn on_callback<F: FnOnce(&InlineKeyboardButtonTypeCallback)>(&self, fnc: F) -> &Self { if let InlineKeyboardButtonType::Callback(t) = self { fnc(t) }; self }
   pub fn on_callback_game<F: FnOnce(&InlineKeyboardButtonTypeCallbackGame)>(&self, fnc: F) -> &Self { if let InlineKeyboardButtonType::CallbackGame(t) = self { fnc(t) }; self }
+  pub fn on_login_url<F: FnOnce(&InlineKeyboardButtonTypeLoginUrl)>(&self, fnc: F) -> &Self { if let InlineKeyboardButtonType::LoginUrl(t) = self { fnc(t) }; self }
   pub fn on_switch_inline<F: FnOnce(&InlineKeyboardButtonTypeSwitchInline)>(&self, fnc: F) -> &Self { if let InlineKeyboardButtonType::SwitchInline(t) = self { fnc(t) }; self }
   pub fn on_url<F: FnOnce(&InlineKeyboardButtonTypeUrl)>(&self, fnc: F) -> &Self { if let InlineKeyboardButtonType::Url(t) = self { fnc(t) }; self }
 
   pub fn as_buy(&self) -> Option<&InlineKeyboardButtonTypeBuy> { if let InlineKeyboardButtonType::Buy(t) = self { return Some(t) } None }
   pub fn as_callback(&self) -> Option<&InlineKeyboardButtonTypeCallback> { if let InlineKeyboardButtonType::Callback(t) = self { return Some(t) } None }
   pub fn as_callback_game(&self) -> Option<&InlineKeyboardButtonTypeCallbackGame> { if let InlineKeyboardButtonType::CallbackGame(t) = self { return Some(t) } None }
+  pub fn as_login_url(&self) -> Option<&InlineKeyboardButtonTypeLoginUrl> { if let InlineKeyboardButtonType::LoginUrl(t) = self { return Some(t) } None }
   pub fn as_switch_inline(&self) -> Option<&InlineKeyboardButtonTypeSwitchInline> { if let InlineKeyboardButtonType::SwitchInline(t) = self { return Some(t) } None }
   pub fn as_url(&self) -> Option<&InlineKeyboardButtonTypeUrl> { if let InlineKeyboardButtonType::Url(t) = self { return Some(t) } None }
 
@@ -107,6 +115,8 @@ impl InlineKeyboardButtonType {
 
   pub fn callback_game<T: AsRef<InlineKeyboardButtonTypeCallbackGame>>(t: T) -> Self { InlineKeyboardButtonType::CallbackGame(t.as_ref().clone()) }
 
+  pub fn login_url<T: AsRef<InlineKeyboardButtonTypeLoginUrl>>(t: T) -> Self { InlineKeyboardButtonType::LoginUrl(t.as_ref().clone()) }
+
   pub fn switch_inline<T: AsRef<InlineKeyboardButtonTypeSwitchInline>>(t: T) -> Self { InlineKeyboardButtonType::SwitchInline(t.as_ref().clone()) }
 
   pub fn url<T: AsRef<InlineKeyboardButtonTypeUrl>>(t: T) -> Self { InlineKeyboardButtonType::Url(t.as_ref().clone()) }
@@ -307,6 +317,94 @@ impl AsRef<InlineKeyboardButtonTypeCallbackGame> for RTDInlineKeyboardButtonType
 
 
 
+/// A button that opens a specified URL and automatically logs in in current user if they allowed to do that
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct InlineKeyboardButtonTypeLoginUrl {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// HTTP URL to open
+  url: String,
+  /// Unique button identifier
+  id: i64,
+  /// If non-empty, new text of the button in forwarded messages
+  forward_text: String,
+  
+}
+
+impl RObject for InlineKeyboardButtonTypeLoginUrl {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "inlineKeyboardButtonTypeLoginUrl" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDInlineKeyboardButtonType for InlineKeyboardButtonTypeLoginUrl {}
+
+
+
+impl InlineKeyboardButtonTypeLoginUrl {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDInlineKeyboardButtonTypeLoginUrlBuilder {
+    let mut inner = InlineKeyboardButtonTypeLoginUrl::default();
+    inner.td_name = "inlineKeyboardButtonTypeLoginUrl".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDInlineKeyboardButtonTypeLoginUrlBuilder { inner }
+  }
+
+  pub fn url(&self) -> &String { &self.url }
+
+  pub fn id(&self) -> i64 { self.id }
+
+  pub fn forward_text(&self) -> &String { &self.forward_text }
+
+}
+
+#[doc(hidden)]
+pub struct RTDInlineKeyboardButtonTypeLoginUrlBuilder {
+  inner: InlineKeyboardButtonTypeLoginUrl
+}
+
+impl RTDInlineKeyboardButtonTypeLoginUrlBuilder {
+  pub fn build(&self) -> InlineKeyboardButtonTypeLoginUrl { self.inner.clone() }
+
+   
+  pub fn url<T: AsRef<str>>(&mut self, url: T) -> &mut Self {
+    self.inner.url = url.as_ref().to_string();
+    self
+  }
+
+   
+  pub fn id(&mut self, id: i64) -> &mut Self {
+    self.inner.id = id;
+    self
+  }
+
+   
+  pub fn forward_text<T: AsRef<str>>(&mut self, forward_text: T) -> &mut Self {
+    self.inner.forward_text = forward_text.as_ref().to_string();
+    self
+  }
+
+}
+
+impl AsRef<InlineKeyboardButtonTypeLoginUrl> for InlineKeyboardButtonTypeLoginUrl {
+  fn as_ref(&self) -> &InlineKeyboardButtonTypeLoginUrl { self }
+}
+
+impl AsRef<InlineKeyboardButtonTypeLoginUrl> for RTDInlineKeyboardButtonTypeLoginUrlBuilder {
+  fn as_ref(&self) -> &InlineKeyboardButtonTypeLoginUrl { &self.inner }
+}
+
+
+
+
+
+
+
 /// A button that forces an inline query to the bot to be inserted in the input field
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InlineKeyboardButtonTypeSwitchInline {
