@@ -18,6 +18,11 @@ pub use self::audio::*;
 pub use self::authentication_code_info::*;
 pub use self::authentication_code_type::*;
 pub use self::authorization_state::*;
+pub use self::auto_download_settings::*;
+pub use self::auto_download_settings_presets::*;
+pub use self::background::*;
+pub use self::background_type::*;
+pub use self::backgrounds::*;
 pub use self::basic_group::*;
 pub use self::basic_group_full_info::*;
 pub use self::bot_command::*;
@@ -26,6 +31,7 @@ pub use self::call::*;
 pub use self::call_connection::*;
 pub use self::call_discard_reason::*;
 pub use self::call_id::*;
+pub use self::call_problem::*;
 pub use self::call_protocol::*;
 pub use self::call_state::*;
 pub use self::callback_query_answer::*;
@@ -43,6 +49,7 @@ pub use self::chat_member_status::*;
 pub use self::chat_members::*;
 pub use self::chat_members_filter::*;
 pub use self::chat_notification_settings::*;
+pub use self::chat_permissions::*;
 pub use self::chat_photo::*;
 pub use self::chat_report_reason::*;
 pub use self::chat_report_spam_state::*;
@@ -63,6 +70,7 @@ pub use self::device_token::*;
 pub use self::document::*;
 pub use self::draft_message::*;
 pub use self::email_address_authentication_code_info::*;
+pub use self::emojis::*;
 pub use self::encrypted_credentials::*;
 pub use self::encrypted_passport_element::*;
 pub use self::error::*;
@@ -83,6 +91,7 @@ pub use self::inline_keyboard_button::*;
 pub use self::inline_keyboard_button_type::*;
 pub use self::inline_query_result::*;
 pub use self::inline_query_results::*;
+pub use self::input_background::*;
 pub use self::input_credentials::*;
 pub use self::input_file::*;
 pub use self::input_identity_document::*;
@@ -117,8 +126,10 @@ pub use self::message::*;
 pub use self::message_content::*;
 pub use self::message_forward_info::*;
 pub use self::message_forward_origin::*;
+pub use self::message_link_info::*;
 pub use self::message_sending_state::*;
 pub use self::messages::*;
+pub use self::minithumbnail::*;
 pub use self::network_statistics::*;
 pub use self::network_statistics_entry::*;
 pub use self::network_type::*;
@@ -153,6 +164,7 @@ pub use self::payment_result::*;
 pub use self::payments_provider_stripe::*;
 pub use self::personal_details::*;
 pub use self::personal_document::*;
+pub use self::phone_number_authentication_settings::*;
 pub use self::photo::*;
 pub use self::photo_size::*;
 pub use self::poll::*;
@@ -178,7 +190,6 @@ pub use self::session::*;
 pub use self::sessions::*;
 pub use self::shipping_option::*;
 pub use self::sticker::*;
-pub use self::sticker_emojis::*;
 pub use self::sticker_set::*;
 pub use self::sticker_set_info::*;
 pub use self::sticker_sets::*;
@@ -226,8 +237,6 @@ pub use self::venue::*;
 pub use self::video::*;
 pub use self::video_note::*;
 pub use self::voice_note::*;
-pub use self::wallpaper::*;
-pub use self::wallpapers::*;
 pub use self::web_page::*;
 pub use self::web_page_instant_view::*;
 
@@ -242,6 +251,11 @@ mod audio;
 mod authentication_code_info;
 mod authentication_code_type;
 mod authorization_state;
+mod auto_download_settings;
+mod auto_download_settings_presets;
+mod background;
+mod background_type;
+mod backgrounds;
 mod basic_group;
 mod basic_group_full_info;
 mod bot_command;
@@ -250,6 +264,7 @@ mod call;
 mod call_connection;
 mod call_discard_reason;
 mod call_id;
+mod call_problem;
 mod call_protocol;
 mod call_state;
 mod callback_query_answer;
@@ -267,6 +282,7 @@ mod chat_member_status;
 mod chat_members;
 mod chat_members_filter;
 mod chat_notification_settings;
+mod chat_permissions;
 mod chat_photo;
 mod chat_report_reason;
 mod chat_report_spam_state;
@@ -287,6 +303,7 @@ mod device_token;
 mod document;
 mod draft_message;
 mod email_address_authentication_code_info;
+mod emojis;
 mod encrypted_credentials;
 mod encrypted_passport_element;
 mod error;
@@ -307,6 +324,7 @@ mod inline_keyboard_button;
 mod inline_keyboard_button_type;
 mod inline_query_result;
 mod inline_query_results;
+mod input_background;
 mod input_credentials;
 mod input_file;
 mod input_identity_document;
@@ -341,8 +359,10 @@ mod message;
 mod message_content;
 mod message_forward_info;
 mod message_forward_origin;
+mod message_link_info;
 mod message_sending_state;
 mod messages;
+mod minithumbnail;
 mod network_statistics;
 mod network_statistics_entry;
 mod network_type;
@@ -377,6 +397,7 @@ mod payment_result;
 mod payments_provider_stripe;
 mod personal_details;
 mod personal_document;
+mod phone_number_authentication_settings;
 mod photo;
 mod photo_size;
 mod poll;
@@ -402,7 +423,6 @@ mod session;
 mod sessions;
 mod shipping_option;
 mod sticker;
-mod sticker_emojis;
 mod sticker_set;
 mod sticker_set_info;
 mod sticker_sets;
@@ -450,8 +470,6 @@ mod venue;
 mod video;
 mod video_note;
 mod voice_note;
-mod wallpaper;
-mod wallpapers;
 mod web_page;
 mod web_page_instant_view;
 
