@@ -15,16 +15,16 @@ pub struct PasswordState {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// True if a 2-step verification password is set
+  /// True, if a 2-step verification password is set
   has_password: bool,
-  /// Hint for the password; can be empty
+  /// Hint for the password; may be empty
   password_hint: String,
-  /// True if a recovery email is set
+  /// True, if a recovery email is set
   has_recovery_email_address: bool,
-  /// True if some Telegram Passport elements were saved
+  /// True, if some Telegram Passport elements were saved
   has_passport_data: bool,
-  /// Pattern of the email address to which the confirmation email was sent
-  unconfirmed_recovery_email_address_pattern: String,
+  /// Information about the recovery email address to which the confirmation email was sent; may be null
+  recovery_email_address_code_info: Option<EmailAddressAuthenticationCodeInfo>,
   
 }
 
@@ -53,7 +53,7 @@ impl PasswordState {
 
   pub fn has_passport_data(&self) -> bool { self.has_passport_data }
 
-  pub fn unconfirmed_recovery_email_address_pattern(&self) -> &String { &self.unconfirmed_recovery_email_address_pattern }
+  pub fn recovery_email_address_code_info(&self) -> &Option<EmailAddressAuthenticationCodeInfo> { &self.recovery_email_address_code_info }
 
 }
 
@@ -90,8 +90,8 @@ impl RTDPasswordStateBuilder {
   }
 
    
-  pub fn unconfirmed_recovery_email_address_pattern<T: AsRef<str>>(&mut self, unconfirmed_recovery_email_address_pattern: T) -> &mut Self {
-    self.inner.unconfirmed_recovery_email_address_pattern = unconfirmed_recovery_email_address_pattern.as_ref().to_string();
+  pub fn recovery_email_address_code_info<T: AsRef<EmailAddressAuthenticationCodeInfo>>(&mut self, recovery_email_address_code_info: T) -> &mut Self {
+    self.inner.recovery_email_address_code_info = Some(recovery_email_address_code_info.as_ref().clone());
     self
   }
 
