@@ -21,20 +21,24 @@ pub struct StickerSet {
   title: String,
   /// Name of the sticker set
   name: String,
+  /// Sticker set thumbnail in WEBP format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed
+  thumbnail: Option<PhotoSize>,
   /// True, if the sticker set has been installed by the current user
   is_installed: bool,
   /// True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
   is_archived: bool,
   /// True, if the sticker set is official
   is_official: bool,
+  /// True, is the stickers in the set are animated
+  is_animated: bool,
   /// True, if the stickers in the set are masks
   is_masks: bool,
   /// True for already viewed trending sticker sets
   is_viewed: bool,
   /// List of stickers in this set
   stickers: Vec<Sticker>,
-  /// A list of emoji corresponding to the stickers in the same order
-  emojis: Vec<StickerEmojis>,
+  /// A list of emoji corresponding to the stickers in the same order. The list is only for informational purposes, because a sticker is always sent with a fixed emoji from the corresponding Sticker object
+  emojis: Vec<Emojis>,
   
 }
 
@@ -61,19 +65,23 @@ impl StickerSet {
 
   pub fn name(&self) -> &String { &self.name }
 
+  pub fn thumbnail(&self) -> &Option<PhotoSize> { &self.thumbnail }
+
   pub fn is_installed(&self) -> bool { self.is_installed }
 
   pub fn is_archived(&self) -> bool { self.is_archived }
 
   pub fn is_official(&self) -> bool { self.is_official }
 
+  pub fn is_animated(&self) -> bool { self.is_animated }
+
   pub fn is_masks(&self) -> bool { self.is_masks }
 
   pub fn is_viewed(&self) -> bool { self.is_viewed }
 
   pub fn stickers(&self) -> &Vec<Sticker> { &self.stickers }
 
-  pub fn emojis(&self) -> &Vec<StickerEmojis> { &self.emojis }
+  pub fn emojis(&self) -> &Vec<Emojis> { &self.emojis }
 
 }
 
@@ -104,6 +112,12 @@ impl RTDStickerSetBuilder {
   }
 
    
+  pub fn thumbnail<T: AsRef<PhotoSize>>(&mut self, thumbnail: T) -> &mut Self {
+    self.inner.thumbnail = Some(thumbnail.as_ref().clone());
+    self
+  }
+
+   
   pub fn is_installed(&mut self, is_installed: bool) -> &mut Self {
     self.inner.is_installed = is_installed;
     self
@@ -122,6 +136,12 @@ impl RTDStickerSetBuilder {
   }
 
    
+  pub fn is_animated(&mut self, is_animated: bool) -> &mut Self {
+    self.inner.is_animated = is_animated;
+    self
+  }
+
+   
   pub fn is_masks(&mut self, is_masks: bool) -> &mut Self {
     self.inner.is_masks = is_masks;
     self
@@ -140,7 +160,7 @@ impl RTDStickerSetBuilder {
   }
 
    
-  pub fn emojis(&mut self, emojis: Vec<StickerEmojis>) -> &mut Self {
+  pub fn emojis(&mut self, emojis: Vec<Emojis>) -> &mut Self {
     self.inner.emojis = emojis;
     self
   }
