@@ -25,8 +25,6 @@ pub struct Supergroup {
   status: ChatMemberStatus,
   /// Member count; 0 if unknown. Currently it is guaranteed to be known only if the supergroup or channel was found through SearchPublicChats
   member_count: i64,
-  /// True, if any member of the supergroup can invite other members. This field has no meaning for channels
-  anyone_can_invite: bool,
   /// True, if messages sent to the channel should contain information about the sender. This field is only applicable to channels
   sign_messages: bool,
   /// True, if the supergroup is a channel
@@ -35,6 +33,8 @@ pub struct Supergroup {
   is_verified: bool,
   /// If non-empty, contains the reason why access to this supergroup or channel must be restricted. Format of the string is "{type}: {description}". {type} Contains the type of the restriction and at least one of the suffixes "-all", "-ios", "-android", or "-wp", which describe the platforms on which access should be restricted. (For example, "terms-ios-android". {description} contains a human-readable description of the restriction, which can be shown to the user)
   restriction_reason: String,
+  /// True, if many users reported this supergroup as a scam
+  is_scam: bool,
   
 }
 
@@ -65,8 +65,6 @@ impl Supergroup {
 
   pub fn member_count(&self) -> i64 { self.member_count }
 
-  pub fn anyone_can_invite(&self) -> bool { self.anyone_can_invite }
-
   pub fn sign_messages(&self) -> bool { self.sign_messages }
 
   pub fn is_channel(&self) -> bool { self.is_channel }
@@ -75,6 +73,8 @@ impl Supergroup {
 
   pub fn restriction_reason(&self) -> &String { &self.restriction_reason }
 
+  pub fn is_scam(&self) -> bool { self.is_scam }
+
 }
 
 #[doc(hidden)]
@@ -116,12 +116,6 @@ impl RTDSupergroupBuilder {
   }
 
    
-  pub fn anyone_can_invite(&mut self, anyone_can_invite: bool) -> &mut Self {
-    self.inner.anyone_can_invite = anyone_can_invite;
-    self
-  }
-
-   
   pub fn sign_messages(&mut self, sign_messages: bool) -> &mut Self {
     self.inner.sign_messages = sign_messages;
     self
@@ -145,6 +139,12 @@ impl RTDSupergroupBuilder {
     self
   }
 
+   
+  pub fn is_scam(&mut self, is_scam: bool) -> &mut Self {
+    self.inner.is_scam = is_scam;
+    self
+  }
+
 }
 
 impl AsRef<Supergroup> for Supergroup {
