@@ -25,6 +25,8 @@ pub enum SupergroupMembersFilter {
   Banned(SupergroupMembersFilterBanned),
   /// Returns bot members of the supergroup or channel
   Bots(SupergroupMembersFilterBots),
+  /// Returns contacts of the user, which are members of the supergroup or channel
+  Contacts(SupergroupMembersFilterContacts),
   /// Returns recently active users in reverse chronological order
   Recent(SupergroupMembersFilterRecent),
   /// Returns restricted supergroup members; can be used only by administrators
@@ -46,6 +48,7 @@ impl<'de> Deserialize<'de> for SupergroupMembersFilter {
       (supergroupMembersFilterAdministrators, Administrators);
       (supergroupMembersFilterBanned, Banned);
       (supergroupMembersFilterBots, Bots);
+      (supergroupMembersFilterContacts, Contacts);
       (supergroupMembersFilterRecent, Recent);
       (supergroupMembersFilterRestricted, Restricted);
       (supergroupMembersFilterSearch, Search);
@@ -60,6 +63,7 @@ impl RObject for SupergroupMembersFilter {
       SupergroupMembersFilter::Administrators(t) => t.td_name(),
       SupergroupMembersFilter::Banned(t) => t.td_name(),
       SupergroupMembersFilter::Bots(t) => t.td_name(),
+      SupergroupMembersFilter::Contacts(t) => t.td_name(),
       SupergroupMembersFilter::Recent(t) => t.td_name(),
       SupergroupMembersFilter::Restricted(t) => t.td_name(),
       SupergroupMembersFilter::Search(t) => t.td_name(),
@@ -72,6 +76,7 @@ impl RObject for SupergroupMembersFilter {
       SupergroupMembersFilter::Administrators(t) => t.extra(),
       SupergroupMembersFilter::Banned(t) => t.extra(),
       SupergroupMembersFilter::Bots(t) => t.extra(),
+      SupergroupMembersFilter::Contacts(t) => t.extra(),
       SupergroupMembersFilter::Recent(t) => t.extra(),
       SupergroupMembersFilter::Restricted(t) => t.extra(),
       SupergroupMembersFilter::Search(t) => t.extra(),
@@ -89,6 +94,7 @@ impl SupergroupMembersFilter {
   pub fn is_administrators(&self) -> bool { if let SupergroupMembersFilter::Administrators(_) = self { true } else { false } }
   pub fn is_banned(&self) -> bool { if let SupergroupMembersFilter::Banned(_) = self { true } else { false } }
   pub fn is_bots(&self) -> bool { if let SupergroupMembersFilter::Bots(_) = self { true } else { false } }
+  pub fn is_contacts(&self) -> bool { if let SupergroupMembersFilter::Contacts(_) = self { true } else { false } }
   pub fn is_recent(&self) -> bool { if let SupergroupMembersFilter::Recent(_) = self { true } else { false } }
   pub fn is_restricted(&self) -> bool { if let SupergroupMembersFilter::Restricted(_) = self { true } else { false } }
   pub fn is_search(&self) -> bool { if let SupergroupMembersFilter::Search(_) = self { true } else { false } }
@@ -96,6 +102,7 @@ impl SupergroupMembersFilter {
   pub fn on_administrators<F: FnOnce(&SupergroupMembersFilterAdministrators)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Administrators(t) = self { fnc(t) }; self }
   pub fn on_banned<F: FnOnce(&SupergroupMembersFilterBanned)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Banned(t) = self { fnc(t) }; self }
   pub fn on_bots<F: FnOnce(&SupergroupMembersFilterBots)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Bots(t) = self { fnc(t) }; self }
+  pub fn on_contacts<F: FnOnce(&SupergroupMembersFilterContacts)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Contacts(t) = self { fnc(t) }; self }
   pub fn on_recent<F: FnOnce(&SupergroupMembersFilterRecent)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Recent(t) = self { fnc(t) }; self }
   pub fn on_restricted<F: FnOnce(&SupergroupMembersFilterRestricted)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Restricted(t) = self { fnc(t) }; self }
   pub fn on_search<F: FnOnce(&SupergroupMembersFilterSearch)>(&self, fnc: F) -> &Self { if let SupergroupMembersFilter::Search(t) = self { fnc(t) }; self }
@@ -103,6 +110,7 @@ impl SupergroupMembersFilter {
   pub fn as_administrators(&self) -> Option<&SupergroupMembersFilterAdministrators> { if let SupergroupMembersFilter::Administrators(t) = self { return Some(t) } None }
   pub fn as_banned(&self) -> Option<&SupergroupMembersFilterBanned> { if let SupergroupMembersFilter::Banned(t) = self { return Some(t) } None }
   pub fn as_bots(&self) -> Option<&SupergroupMembersFilterBots> { if let SupergroupMembersFilter::Bots(t) = self { return Some(t) } None }
+  pub fn as_contacts(&self) -> Option<&SupergroupMembersFilterContacts> { if let SupergroupMembersFilter::Contacts(t) = self { return Some(t) } None }
   pub fn as_recent(&self) -> Option<&SupergroupMembersFilterRecent> { if let SupergroupMembersFilter::Recent(t) = self { return Some(t) } None }
   pub fn as_restricted(&self) -> Option<&SupergroupMembersFilterRestricted> { if let SupergroupMembersFilter::Restricted(t) = self { return Some(t) } None }
   pub fn as_search(&self) -> Option<&SupergroupMembersFilterSearch> { if let SupergroupMembersFilter::Search(t) = self { return Some(t) } None }
@@ -115,6 +123,8 @@ impl SupergroupMembersFilter {
 
   pub fn bots<T: AsRef<SupergroupMembersFilterBots>>(t: T) -> Self { SupergroupMembersFilter::Bots(t.as_ref().clone()) }
 
+  pub fn contacts<T: AsRef<SupergroupMembersFilterContacts>>(t: T) -> Self { SupergroupMembersFilter::Contacts(t.as_ref().clone()) }
+
   pub fn recent<T: AsRef<SupergroupMembersFilterRecent>>(t: T) -> Self { SupergroupMembersFilter::Recent(t.as_ref().clone()) }
 
   pub fn restricted<T: AsRef<SupergroupMembersFilterRestricted>>(t: T) -> Self { SupergroupMembersFilter::Restricted(t.as_ref().clone()) }
@@ -317,6 +327,74 @@ impl AsRef<SupergroupMembersFilterBots> for RTDSupergroupMembersFilterBotsBuilde
 
 
 
+/// Returns contacts of the user, which are members of the supergroup or channel
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct SupergroupMembersFilterContacts {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Query to search for
+  query: String,
+  
+}
+
+impl RObject for SupergroupMembersFilterContacts {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "supergroupMembersFilterContacts" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDSupergroupMembersFilter for SupergroupMembersFilterContacts {}
+
+
+
+impl SupergroupMembersFilterContacts {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDSupergroupMembersFilterContactsBuilder {
+    let mut inner = SupergroupMembersFilterContacts::default();
+    inner.td_name = "supergroupMembersFilterContacts".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDSupergroupMembersFilterContactsBuilder { inner }
+  }
+
+  pub fn query(&self) -> &String { &self.query }
+
+}
+
+#[doc(hidden)]
+pub struct RTDSupergroupMembersFilterContactsBuilder {
+  inner: SupergroupMembersFilterContacts
+}
+
+impl RTDSupergroupMembersFilterContactsBuilder {
+  pub fn build(&self) -> SupergroupMembersFilterContacts { self.inner.clone() }
+
+   
+  pub fn query<T: AsRef<str>>(&mut self, query: T) -> &mut Self {
+    self.inner.query = query.as_ref().to_string();
+    self
+  }
+
+}
+
+impl AsRef<SupergroupMembersFilterContacts> for SupergroupMembersFilterContacts {
+  fn as_ref(&self) -> &SupergroupMembersFilterContacts { self }
+}
+
+impl AsRef<SupergroupMembersFilterContacts> for RTDSupergroupMembersFilterContactsBuilder {
+  fn as_ref(&self) -> &SupergroupMembersFilterContacts { &self.inner }
+}
+
+
+
+
+
+
+
 /// Returns recently active users in reverse chronological order
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct SupergroupMembersFilterRecent {
