@@ -6,7 +6,7 @@ use uuid::Uuid;
 
 
 
-/// Contains full information about a user
+/// Contains full information about a user (except the full list of profile photos)
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct UserFullInfo {
   #[doc(hidden)]
@@ -15,30 +15,20 @@ pub struct UserFullInfo {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// User profile photo; may be null
-  photo: Option<ChatPhoto>,
-  /// True, if the user is blocked by the current user
+  /// True, if the user is blacklisted by the current user
   is_blocked: bool,
   /// True, if the user can be called
   can_be_called: bool,
-  /// True, if a video call can be created with the user
-  supports_video_calls: bool,
   /// True, if the user can't be called due to their privacy settings
   has_private_calls: bool,
-  /// True, if the user can't be linked in forwarded messages due to their privacy settings
-  has_private_forwards: bool,
-  /// True, if the current user needs to explicitly allow to share their phone number with the user when the method addContact is used
-  need_phone_number_privacy_exception: bool,
   /// A short user bio
   bio: String,
-  /// For bots, the text that is shown on the bot's profile page and is sent together with the link when users share the bot
+  /// For bots, the text that is included with the link when users share the bot
   share_text: String,
-  /// Contains full information about a user
-  description: String,
   /// Number of group chats where both the other user and the current user are a member; 0 for the current user
   group_in_common_count: i64,
-  /// For bots, list of the bot commands
-  commands: Vec<BotCommand>,
+  /// If the user is a bot, information about the bot; may be null
+  bot_info: Option<BotInfo>,
   
 }
 
@@ -59,29 +49,19 @@ impl UserFullInfo {
     RTDUserFullInfoBuilder { inner }
   }
 
-  pub fn photo(&self) -> &Option<ChatPhoto> { &self.photo }
-
   pub fn is_blocked(&self) -> bool { self.is_blocked }
 
   pub fn can_be_called(&self) -> bool { self.can_be_called }
 
-  pub fn supports_video_calls(&self) -> bool { self.supports_video_calls }
-
   pub fn has_private_calls(&self) -> bool { self.has_private_calls }
 
-  pub fn has_private_forwards(&self) -> bool { self.has_private_forwards }
-
-  pub fn need_phone_number_privacy_exception(&self) -> bool { self.need_phone_number_privacy_exception }
-
   pub fn bio(&self) -> &String { &self.bio }
 
   pub fn share_text(&self) -> &String { &self.share_text }
 
-  pub fn description(&self) -> &String { &self.description }
-
   pub fn group_in_common_count(&self) -> i64 { self.group_in_common_count }
 
-  pub fn commands(&self) -> &Vec<BotCommand> { &self.commands }
+  pub fn bot_info(&self) -> &Option<BotInfo> { &self.bot_info }
 
 }
 
@@ -94,12 +74,6 @@ impl RTDUserFullInfoBuilder {
   pub fn build(&self) -> UserFullInfo { self.inner.clone() }
 
    
-  pub fn photo<T: AsRef<ChatPhoto>>(&mut self, photo: T) -> &mut Self {
-    self.inner.photo = Some(photo.as_ref().clone());
-    self
-  }
-
-   
   pub fn is_blocked(&mut self, is_blocked: bool) -> &mut Self {
     self.inner.is_blocked = is_blocked;
     self
@@ -112,30 +86,12 @@ impl RTDUserFullInfoBuilder {
   }
 
    
-  pub fn supports_video_calls(&mut self, supports_video_calls: bool) -> &mut Self {
-    self.inner.supports_video_calls = supports_video_calls;
-    self
-  }
-
-   
   pub fn has_private_calls(&mut self, has_private_calls: bool) -> &mut Self {
     self.inner.has_private_calls = has_private_calls;
     self
   }
 
    
-  pub fn has_private_forwards(&mut self, has_private_forwards: bool) -> &mut Self {
-    self.inner.has_private_forwards = has_private_forwards;
-    self
-  }
-
-   
-  pub fn need_phone_number_privacy_exception(&mut self, need_phone_number_privacy_exception: bool) -> &mut Self {
-    self.inner.need_phone_number_privacy_exception = need_phone_number_privacy_exception;
-    self
-  }
-
-   
   pub fn bio<T: AsRef<str>>(&mut self, bio: T) -> &mut Self {
     self.inner.bio = bio.as_ref().to_string();
     self
@@ -148,20 +104,14 @@ impl RTDUserFullInfoBuilder {
   }
 
    
-  pub fn description<T: AsRef<str>>(&mut self, description: T) -> &mut Self {
-    self.inner.description = description.as_ref().to_string();
-    self
-  }
-
-   
   pub fn group_in_common_count(&mut self, group_in_common_count: i64) -> &mut Self {
     self.inner.group_in_common_count = group_in_common_count;
     self
   }
 
    
-  pub fn commands(&mut self, commands: Vec<BotCommand>) -> &mut Self {
-    self.inner.commands = commands;
+  pub fn bot_info<T: AsRef<BotInfo>>(&mut self, bot_info: T) -> &mut Self {
+    self.inner.bot_info = Some(bot_info.as_ref().clone());
     self
   }
 
